var v_ids = ['air_temp_max', 'air_temp_min', 'air_temp_mean', 
    'rh_max', 'rh_min', 'rh_mean', 
    'wind_speed_max', 'wind_speed_mean', 'wind_dir_mean', 
    'precip_total', 
    'solar_rad_total', 
    'soil_temp_max', 'soil_temp_min', 'soil_temp_mean'];


function plotExt(id, y_axis_label, series) {

    var plot = $.jqplot (id, series,
        {
            axes: {xaxis: {renderer: $.jqplot.DateAxisRenderer, label: 'Date', 
                    rendererOptions:{
                        tickRenderer:$.jqplot.CanvasAxisTickRenderer},
                    tickOptions: {angle: -40}}, 
                yaxis: {labelRenderer: $.jqplot.CanvasAxisLabelRenderer, label: y_axis_label}},
            series: [
                {label: 'Max', showMarker: false, color: '#990012'},
                {label: 'Mean', showMarker: false, color: '#000000'}, 
                {label: 'Min', showMarker: false, color: '#2B65EC'}],
            legend: {show: true, placement: 'insideGrid', location: 'ne'}
        }
    );

    return plot
};


$(document).ready(function() {

    var data_cols = {};
    data_cols['rdt'] = [];

    for (i in v_ids) {

        data_cols[v_ids[i]] = [];
    };

    var data_table_rows = $("#id_timeseries").contents().find("tr");
    var count = 0;

    while (count < data_table_rows.length) {

        var d = $("#id_" + count + "_date").text();
        var t = $("#id_" + count + "_time").text();
        var rdt = d + " " + t;

        data_cols['rdt'].push(rdt);

        for (i in v_ids) {

            var td = $("#id_" + count + "_" + v_ids[i]);

            if (td) {

                var value_str = td.text();
                var value = parseFloat(value_str);
                var value_array = [rdt, value];

                data_cols[v_ids[i]].push(value_array);
            };
        };

        count = count + 1;     
    };

    var t = $("#id_air_temperature_plot");
    var rh = $("#id_rh_plot");
    var ws = $("#id_wind_speed_plot");
    var wd = $("#id_wind_direction_plot");
    var p = $("#id_precipitation_plot");
    var sr = $("#id_solar_radiation_plot");
    var stp = $("#id_soil_temperature_plot");

    if (t.length > 0) {

        var temperature_units = $("#id_air_temperature_units").text();
        var temperature_plot = plotExt('id_air_temperature_plot', temperature_units, [data_cols['air_temp_max'], data_cols['air_temp_mean'], data_cols['air_temp_min']]);
    };

    if (rh.length > 0) {

        var rh_plot = plotExt('id_rh_plot', '%', [data_cols['rh_max'], data_cols['rh_mean'], data_cols['rh_min']]);
    };

    if (ws.length > 0) {

        var wind_speed_units = $("#id_wind_speed_units").text();
        var wind_speed_plot = $.jqplot ('id_wind_speed_plot', [data_cols['wind_speed_max'], data_cols['wind_speed_mean']],
            {
                axes: {xaxis: {renderer: $.jqplot.DateAxisRenderer, label: 'Date (MST)', 
                        rendererOptions:{tickRenderer:$.jqplot.CanvasAxisTickRenderer},
                        tickOptions: {angle: -40}}, 
                    yaxis: {labelRenderer: $.jqplot.CanvasAxisLabelRenderer, label: wind_speed_units}},
                series: [
                    {label: 'Max', showMarker: false, color: '#990012'},
                    {label: 'Mean', showMarker: false, color: '#000000'}],
                legend: {show: true, placement: 'insideGrid', location: 'ne'}
            }
        );
    };

    if (wd.length > 0) {

        var wind_direction_plot = $.jqplot ('id_wind_direction_plot', [data_cols['wind_dir_mean']],
            {
                axes: {xaxis: {renderer: $.jqplot.DateAxisRenderer, label: 'Date (MST)', 
                        rendererOptions:{tickRenderer:$.jqplot.CanvasAxisTickRenderer},
                        tickOptions: {angle: -40}}, 
                    yaxis: {labelRenderer: $.jqplot.CanvasAxisLabelRenderer, label: 'deg.'}},
                series: [{label: 'Mean', showMarker: false, color: '#000000'}],
                legend: {show: true, placement: 'insideGrid', location: 'ne'}
            }
        );
    };

    if (p.length > 0) {

        var precipitation_units = $("#id_precipitation_units").text();
        var precipitation_plot = $.jqplot ('id_precipitation_plot', [data_cols['precip_total']],
            {
                axes: {xaxis: {renderer: $.jqplot.DateAxisRenderer, label: 'Date (MST)', 
                        rendererOptions:{tickRenderer:$.jqplot.CanvasAxisTickRenderer},
                        tickOptions: {angle: -40}},
                    yaxis: {labelRenderer: $.jqplot.CanvasAxisLabelRenderer, label: precipitation_units}},
                seriesDefaults: {renderer: $.jqplot.BarRenderer, 
                        rendererOptions: {fillToZero: true, barDirection: 'vertical', barWidth: 3}},
                series: [{label: 'Total', color: '#2B65EC'}],
                legend: {show: true, placement: 'insideGrid', location: 'nw'}
            }
        );
    };

    if (sr.length > 0) {

        var solar_radiation_units = $("#id_solar_radiation_units").text();
        var solar_radiation_plot = $.jqplot ('id_solar_radiation_plot', [data_cols['solar_rad_total']],
            {
                axes: {xaxis: {renderer: $.jqplot.DateAxisRenderer, label: 'Date', 
                        rendererOptions:{tickRenderer:$.jqplot.CanvasAxisTickRenderer},
                        tickOptions: {angle: -40}},
                    yaxis: {labelRenderer: $.jqplot.CanvasAxisLabelRenderer, label: solar_radiation_units}},
                seriesDefaults: {renderer: $.jqplot.BarRenderer, 
                        rendererOptions: {fillToZero: true, barDirection: 'vertical', barWidth: 3}},
                series: [{label: 'Total', color: '#2B65EC'}],
                legend: {show: true, placement: 'insideGrid', location: 'nw'}
            }
        );
    };

    if (stp.length > 0) {

        var soil_temperature_units = $("#id_soil_temperature_units").text();
        var soil_temperature_plot = plotExt('id_soil_temperature_plot', soil_temperature_units, [data_cols['soil_temp_max'], data_cols['soil_temp_mean'], data_cols['soil_temp_min']]);
    };
});

